==> calligra_3.1.0+dfsg.orig.tar.xz: calligra-3.1.0/plugins/musicshape/actions/DotsAction.h <==
/* This file is part of the KDE project
 * Copyright 2007 Marijn Kruisselbrink <mkruisselbrink@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef DOTSACTION_H
#define DOTSACTION_H

#include "AbstractNoteMusicAction.h"

class DotsAction : public AbstractNoteMusicAction
{
public:
    explicit DotsAction(SimpleEntryTool *tool);

    virtual void mousePress(MusicCore::Chord* chord, MusicCore::Note* note, qreal distance, const QPointF& pos);

    //! To avoid 'mousePress() was hidden' warning
    virtual void mousePress(MusicCore::Staff* staff, int bar, const QPointF& pos) {
        AbstractNoteMusicAction::mousePress(staff, bar, pos);
    }
    //! To avoid 'mousePress() was hidden' warning
    virtual void mousePress(MusicCore::StaffElement* se, qreal distance, const QPointF& pos) {
        AbstractNoteMusicAction::mousePress(se, distance, pos);
    }
};

#endif // DOTSACTION_H

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/plugins/musicshape/actions/DotsAction.h <==
/* This file is part of the KDE project
 * Copyright 2007 Marijn Kruisselbrink <mkruisselbrink@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef DOTSACTION_H
#define DOTSACTION_H

#include "AbstractNoteMusicAction.h"

class DotsAction : public AbstractNoteMusicAction
{
public:
    explicit DotsAction(SimpleEntryTool *tool);

    void mousePress(MusicCore::Chord* chord, MusicCore::Note* note, qreal distance, const QPointF& pos) override;

    //! To avoid 'mousePress() was hidden' warning
    void mousePress(MusicCore::Staff* staff, int bar, const QPointF& pos) override {
        AbstractNoteMusicAction::mousePress(staff, bar, pos);
    }
    //! To avoid 'mousePress() was hidden' warning
    void mousePress(MusicCore::StaffElement* se, qreal distance, const QPointF& pos) override {
        AbstractNoteMusicAction::mousePress(se, distance, pos);
    }
};

#endif // DOTSACTION_H
